;;; mail-watch.el --- Watch new mail in maildir or others
;; Copyright (C) 2000 Shenghuo ZHU

;; Author: Shenghuo ZHU <zsh@cs.rochester.edu>
;; Created: Thu Jul  6 21:58:09 EDT 2000
;; Keywords: maildir time

;; This file is not a part of GNU Emacs.
;;
;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.
;;
;; This file is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; (require 'mail-watch)
;; (setq mail-watch-files-or-directories '("/my/maildir/new"))
;; (display-time)

;; Make sure display-time-mail-file or the environment variable MAIL
;; is set as a string (whatever it is).

;;; Code:

(require 'advice)
(require 'time)

(defcustom mail-watch-files-or-directories nil
  "The files or directories to watch for new mails."
  :type '(repeat directory)
  :group 'mail)

(defun mail-watch ()
  "Watch new mails.
Return non-nil if there are new mails."
  (let ((files mail-watch-files-or-directories))
    (catch 'found
      (while files
	(cond 
	 ((file-directory-p (car files))
	  (dolist (file (directory-files (car files) t nil t))
	    (and (file-exists-p file)
		 (not (file-directory-p file))
		 (< 0 (nth 7 (file-attributes (file-chase-links file))))
		 (throw 'found t))))
	 ((and (file-exists-p (car files))
	       (< 0 (nth 7 (file-attributes (file-chase-links (car files))))))
	  (throw 'found t))
	 (t nil))
	(setq files (cdr files))))))

(defadvice display-time-file-nonempty-p 
  (around display-time-file-nonempty-p/mail-watch activate)
  (setq ad-return-value (mail-watch)))

(provide 'mail-watch)

;; maildir-watch.el ends here
